==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/da.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Kontakter",
"Save" => "Gem",
"Uploading..." => "Uploader...",
"Importing..." => "Importerer...",
"Preparing..." => "Forbereder...",
"Imported {count} of {total} contacts" => "Importeret {count} af {total} kontakter",
"Imported {imported} contacts. {failed} failed." => "Importeret {imported} kontakter. {failed} fejlede.",
"An address book called {name} already exists" => "Der eksistere allerede en adressebog med navnet: {name}",
"Failed adding address book: {error}" => "Kunne ikke tilføje adressebog: {error}",
"Failed loading address books: {error}" => "Kunne ikke hente adressebøger: {error}",
"Indexing contacts" => "Indekserer kontakter",
"Unrecoverable error loading address books: {msg}" => "Uigenkaldelig fejl ved hentning af adressebøger: {msg}",
"Error." => "Fejl.",
"Add to..." => "Føj til...",
"Remove from..." => "Fjern fra...",
"Add group..." => "Tilføj gruppe...",
"Invalid URL: \"{url}\"" => "Ugyldig URL: \"{url}\"",
"There was an error opening a mail composer." => "Der opstod en fejl under åbning af en e-mail-editor.",
"Invalid email: \"{url}\"" => "Ugyldig email: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Sammenlægning fejlede. Kan ikke finde kontakt: {id}",
"Merge failed." => "Sammenlægning fejlede.",
"Merge failed. Error saving contact." => "Indfletning lykkedes ikke. Fejl ved gemning af kontakt.",
"Select photo" => "Vælg foto",
"Network or server error. Please inform administrator." => "Netværks- eller serverfejl: Informér administrator.",
"Error adding to group." => "Fejl ved tilføjelse til gruppe.",
"Error removing from group." => "Fejl ved fjernelse fra gruppe.",
"Error setting {name} as favorite." => "Kunne ikke indstille {name} som favorit.",
"Merge contacts" => "Sammenlæg kontakter",
"Cancel" => "Annuller",
"Add group" => "Tilføj gruppe",
"OK" => "OK",
"Could not find contact: {id}" => "Kunne ikke finde kontakt: {id}",
"No files selected for upload." => "Der er ikke valgt nogen filer at uploade.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Dr.",
"Edit profile picture" => "Redigér profilbillede",
"Crop photo" => "Beskær billede",
"Is this correct?" => "Er dette korrekt?",
"Error parsing date: {date}" => "Fejl under læsning af dato: {date}",
"# groups" => "# grupper",
"Error parsing birthday {bday}: {error}" => "Fejl under læsning af fødselsdato: {bday}: {error}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Nogle kontakter er markeret til sletning, men er endnu ikke slettet. Vent venligst på, at de bliver slettet.",
"Click to undo deletion of {num} contacts" => "Klik for at fortryde sletning af {num} kontakter",
"Cancelled deletion of {num} contacts" => "annullerede sletning af {num} kontakter",
"Add" => "Tilføj",
"Contact is already in this group." => "Kontaktperson er allerede i denne gruppe.",
"Contacts are already in this group." => "Kontakterpersoner er allerede i denne gruppe.",
"Couldn't get contact list." => "Kunne ikke hente liste over kontaktpersoner.",
"Contact is not in this group." => "Kontaktperson er ikke i denne gruppe.",
"Contacts are not in this group." => "Kontakterpersoner er ikke i denne gruppe.",
"Failed renaming group: {error}" => "Kunne ikke omdøbe gruppe: {error}",
"A group named {group} already exists" => "En gruppe med navnet {group} eksistere allerede",
"You can drag groups to\narrange them as you like." => "Du kan trække grupper til⏎ arrangér dem som du vil.",
"Failed adding group: {error}" => "Kunne ikke tilføje gruppe: {error}",
"All" => "Alle",
"Favorites" => "Foretrukne",
"Shared by {owner}" => "Delt af {owner}",
"Not grouped" => "Ikke i gruppe",
"Failed loading groups: {error}" => "Kunne ikke hente grupper: {error}",
"Please choose the addressbook" => "Vælg venligst adressebog",
"Import into..." => "Importér til...",
"Error loading import template" => "Fejl ved hentning af importskabelon ",
"Import contacts" => "Importer kontakter",
"Import" => "Importer",
"Import done" => "Import fuldført",
"Close" => "Luk",
"Error" => "Fejl",
"Displayname cannot be empty." => "Brugernavn må ikke være tomt.",
"Show CardDav link" => "Vis CardDav link",
"Show read-only VCF link" => "Vis skrivebeskyttet VCF link",
"Download" => "Download",
"Edit" => "Rediger",
"Delete" => "Slet",
"More..." => "Mere...",
"Less..." => "Mindre...",
"Server error! Please inform system administator" => "Server fejl! Informer venligst systemadministratoren.",
"Failed loading photo: {error}" => "Kunne ikke hente billede: {error}",
"You do not have permissions to see this contacts" => "Du har ikke rettigheder til at se denne kontaktperson",
"Contact not found" => "Kontakt ikke fundet",
"You do not have permissions to see these contacts" => "Du har ikke rettigheder til at se disse kontaktpersoner",
"You do not have permissions add contacts to the address book" => "Du har ikke rettigheder til at føje kontaktpersoner til denne adressebog",
"The backend for this address book does not support adding contacts" => "Denne adressebogs system understøtter ikke tilføjelse af kontakter",
"You do not have permissions to delete this contact" => "Du har ikke rettigheder til at slette denne kontaktperson",
"The backend for this address book does not support deleting contacts" => "Denne adressebogs system understøtter ikke sletning af kontakter",
"Unknown error" => "Ukendt fejl",
"The backend for this address book does not support updating" => "Systemet for denne adressebog understøtter ikke opdatering",
"You don't have permissions to update the address book." => "Du har ikke rettigheder til at opdatere denne adressebog",
"You don't have permissions to delete the address book." => "Du har ikke rettigheder til at slette denne adressebog",
"Address book not found" => "Adressebog ikke fundet",
"You do not have permissions to see this contact" => "Du har ikke rettigheder til at se denne kontaktperson",
"You do not have permissions to update this contact" => "Du har ikke rettigheder til at opdatere denne kontaktperson",
"The backend for this contact does not support updating it" => "Systemet for denne kontakt understøtter ikke opdatering",
"This backend not support adding contacts" => "Dette system understøtter ikke tilføjelse af kontakter",
"Property not found" => "Egenskab ikke fundet",
" Missing IM parameter for: " => "Manglende IM-parameter for:",
"Unknown IM: " => "Ukendt IM:",
"{name}'s Birthday" => "{name}s fødselsdag",
"Error creating address book" => "Fejl ved oprettelse af adressebog",
"Error updating address book" => "Fejl ved opdatering af adressebog",
"You do not have permissions to delete the \"%s\" address book" => "Du har ikke tilladelse til at slette \"%s\" adressebog",
"Error deleting address book" => "Fejl ved sletning af adressebog",
"Error creating contact." => "Fejl ved oprettelse af kontaktperson.",
"Error deleting contact." => "Fejl ved sletning af kontaktperson.",
"Error retrieving contact." => "Fejl ved hentning af kontaktperson.",
"Error saving contact." => "Kunne ikke gemme kontaktpersonen.",
"Error removing contact from other address book." => "Fejl ved fjernelse af kontaktperson fra anden adressebog.",
"Couldn't find contact." => "Kunne ikke finde kontakt.",
"No contact data in request." => "Ingen kontakt oplysninger i anmodningen.",
"Error merging into contact." => "Fejl ved indfletning til kontaktperson.",
"Error saving contact to backend." => "Kunne ikke gemme kontakt på server.",
"Property name is not set." => "Egenskabsnavn er ikke angivet.",
"Property checksum is not set." => "Tjeksum for egenskab er ikke angivet.",
"Information about vCard is incorrect. Please reload the page." => "Informationen om vCard er forkert. Genindlæs siden.",
"Error updating contact" => "Kunne ikke opdatere kontakt",
"Error saving contact to backend" => "Kunne ikke gemme kontakt til server",
"Error getting user photo" => "Fejl ved indlæsning af brugerfoto",
"No file was uploaded. Unknown error" => "Ingen fil blev uploadet. Ukendt fejl.",
"There is no error, the file uploaded with success" => "Der skete ingen fejl, filen blev succesfuldt uploadet",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Den uploadede fil er større end upload_max_filesize indstillingen i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
"The uploaded file was only partially uploaded" => "Filen blev kun delvist uploadet.",
"No file was uploaded" => "Ingen fil uploadet",
"Missing a temporary folder" => "Manglende midlertidig mappe.",
"Couldn't load temporary image: " => "Kunne ikke indlæse midlertidigt billede",
"Couldn't save temporary image: " => "Kunne ikke gemme midlertidigt billede: ",
"No photo path was submitted." => "Der blev ikke medsendt en sti til fotoet.",
"File doesn't exist:" => "Filen eksisterer ikke:",
"Error loading image." => "Kunne ikke indlæse billede.",
"Image has been removed from cache" => "Billedet blev fjernet fra cache",
"Error creating temporary image" => "Kunne ikke oprette midlertidigt billede",
"Error cropping image" => "Kunne ikke beskære billedet",
"Error resizing image" => "Kunne ikke ændre billedets størrelse",
"Error getting PHOTO property." => "Fejl ved indlæsning af PHOTO feltet.",
"No group name given." => "Intet gruppenavn givet.",
"Error adding group." => "Fejl ved tilføjelse af gruppe.",
"No group name to rename from given." => "Intet gruppenavn at omdøbe fra det givne.",
"No group name to rename to given." => "Intet gruppenavn at omdøbe til det givne.",
"Error renaming group." => "Fejl ved omdøbning af gruppenavn.",
"Group ID missing from request." => "Gruppe-id mangler i forespørgsel.",
"Group name missing from request." => "Gruppenavn mangler i forespørgsel.",
"Contact ID missing from request." => "Kontaktpersons-id mangler i forespørgsel.",
"Failed to write to disk" => "Fejl ved skrivning til disk.",
"Not enough storage available" => "Der er ikke nok plads til rådlighed",
"Attempt to upload blacklisted file:" => "Forsøg på at oploade sortlistede filer:",
"Error uploading contacts to storage." => "Kunne ikke uploade kontaktepersoner til midlertidig opbevaring.",
"Error moving file to imports folder." => "Kunne ikke flytte filer til importmappe.",
"You do not have permissions to import into this address book." => "Du har ikke rettigheder til at importere til denne adressebog",
"File name missing from request." => "Filnavn mangler fra forespørgsel.",
"Progress key missing from request." => "Fremskridts nøglen mangler fra anmodningen.",
"Attempt to access blacklisted file:" => "Forsøg på at tilgå sortlistet fil:",
"No contacts found in: " => "Ingen kontaktpersoner fundet i:",
"No key is given." => "Ingen værdi er givet.",
"No value is given." => "Ingen værdi er givet.",
"Could not set preference: " => "Kunne ikke sætte præference:",
"Contact" => "Kontaktperson",
"Other" => "Andet",
"HomePage" => "Hjemmeside",
"Jabber" => "Jabber",
"Internet call" => "Internet opkald",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Google Talk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Arbejde",
"Home" => "Hjemme",
"Mobile" => "Mobil",
"Text" => "SMS",
"Voice" => "Telefonsvarer",
"Message" => "Besked",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Personsøger",
"Internet" => "Internet",
"Friends" => "Venner",
"Family" => "Familie",
"New Contact" => "Ny Kontakt",
"Group name" => "Gruppe navn",
"New Group" => "Ny Gruppe",
"Address books" => "Adressebøger",
"Display name" => "Vist navn",
"Add Address Book" => "Tilføj Adressebog",
"Select file..." => "Vælg fil...",
"(De-)select all" => "(Fra)vælg alle",
"Sort order" => "Sorteringsorden",
"First- Lastname" => "For- efernavn",
"Last-, Firstname" => "For-, efternavn",
"Groups" => "Grupper",
"Favorite" => "Foretrukken",
"Merge selected" => "Sammenlæg markerede",
"Keyboard shortcuts" => "Tastaturgenveje",
"Navigation" => "Navigering",
"Next contact in list" => "Næste kontaktperson i listen",
"Previous contact in list" => "Forrige kontaktperson i listen",
"Expand/collapse current addressbook" => "Udvid/sammenfold nuværende adressebog",
"Next addressbook" => "Næste adressebog",
"Previous addressbook" => "Forrige adressebog",
"Actions" => "Handlinger",
"Refresh contacts list" => "Genindlæs kontaktliste",
"Add new contact" => "Tilføj ny kontaktperson",
"Add new addressbook" => "Tilføj ny adressebog",
"Delete current contact" => "Slet aktuelle kontaktperson",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3> Din adressebog er deaktiveret eller indeholder ingen kontakter.</h3><p>Tilføj nye kontakter eller importer eksisterende kontakter fra en VCF fil.</p>",
"Add contact" => "Tilføj kontaktpeson.",
"Delete group" => "Slet gruppe",
"Rename group" => "Omdøb gruppe",
"Which contact should the data be merged into?" => "Hvilken kontaktperson skal data føjes til?",
"Delete the other(s) after successful merge?" => "Slet de andre efter gennemgørt sammenfletning?",
"Compose mail" => "Skriv mail",
"Delete current photo" => "Slet nuværende foto",
"Edit current photo" => "Rediger nuværende foto",
"Upload new photo" => "Upload nyt foto",
"Select photo from ownCloud" => "Vælg foto fra ownCloud",
"Name" => "Navn",
"First name" => "Fornavn",
"Additional names" => "Mellemnavne",
"Last name" => "Efternavn",
"Select groups" => "Vælg grupper",
"Select address book" => "Vælg adressebog",
"Nickname" => "Kaldenavn",
"Enter nickname" => "Indtast kaldenavn",
"Title" => "Titel",
"Enter title" => "Angiv titel",
"Organization" => "Organisation",
"Enter organization" => "Angiv organisation",
"Birthday" => "Fødselsdag",
"Notes go here..." => "Skriv noter her...",
"Export as VCF" => "Exporter som VCF",
"Add field..." => "Tilføj felt...",
"Phone" => "Telefon",
"Email" => "E-mail",
"Instant Messaging" => "Instant Messaging",
"Address" => "Adresse",
"Note" => "Note",
"Web site" => "Hjemmeside",
"Delete contact" => "Slet kontaktperson",
"Preferred" => "Foretrukken",
"Please specify a valid email address." => "Indtast venligst en gyldig email-adresse.",
"someone@example.com" => "nogen@eksempel.com",
"Mail to address" => "Send mail til adresse",
"Delete email address" => "Slet email-adresse",
"Enter phone number" => "Indtast telefonnummer",
"Delete phone number" => "Slet telefonnummer",
"Go to web site" => "Gå til web site",
"Delete URL" => "Slet URL",
"View on map" => "Vis på kort",
"Delete address" => "Slet adresse",
"1600 Pennsylvania Avenue, NW" => "1600 Pennsylvania Avenue, NW",
"Street address" => "Gade",
"20500" => "20500",
"Postal code" => "Postnummer",
"Washington, DC" => "Washington, DC",
"City" => "By",
"District of Columbia" => "District of Columbia",
"State or province" => "Stat eller provins",
"USA" => "USA",
"Country" => "Land",
"Instant Messenger" => "Instant Messenger",
"Delete IM" => "Slet IM",
"Active" => "Aktiv",
"Share" => "Del",
"Export" => "Exporter",
"CardDAV link" => "CardDAV link",
"CardDAV syncing addresses" => "CardDAV synkroniserings adresse",
"more info" => "flere oplysninger",
"Primary address (Kontact et al)" => "Primær adresse (Kontakt o.a.)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressebøger",
"New Address Book" => "Ny adressebog",
"Description" => "Beskrivelse"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/da.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Kontakter",
"Add new LDAP Addressbook" => "Tilføj ny LDAP adressebog",
"Ok" => "OK",
"Cancel" => "Annuller",
"Save" => "Gem",
"Edit Addressbook" => "Rediger adressebog",
"Starting file import" => "Begynd filimport",
"Format selected: {format}" => "Valgt format: {format}",
"Automatic format detection" => "Automatisk format vælger",
"Processing {count}/{total} cards" => "Importeret {count} af {total} kontakter",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Total:{total}, Succes:{imported}, Fejl:{failed}",
"An address book called {name} already exists" => "Der eksistere allerede en adressebog med navnet: {name}",
"Failed adding address book: {error}" => "Kunne ikke tilføje adressebog: {error}",
"Failed loading address books: {error}" => "Kunne ikke hente adressebøger: {error}",
"Server error! Please inform system administator" => "Server fejl! Informer venligst systemadministratoren.",
"Indexing contacts" => "Indekserer kontakter",
"Unrecoverable error loading address books: {msg}" => "Uigenkaldelig fejl ved hentning af adressebøger: {msg}",
"Error." => "Fejl.",
"Add to..." => "Føj til...",
"Remove from..." => "Fjern fra...",
"Add group..." => "Tilføj gruppe...",
"Invalid URL: \"{url}\"" => "Ugyldig URL: \"{url}\"",
"Invalid email: \"{url}\"" => "Ugyldig email: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Sammenlægning fejlede. Kan ikke finde kontakt: {id}",
"Merge failed." => "Sammenlægning fejlede.",
"Merge failed. Error saving contact." => "Indfletning lykkedes ikke. Fejl ved gemning af kontakt.",
"Select photo" => "Vælg foto",
"Network or server error. Please inform administrator." => "Netværks- eller serverfejl: Informér administrator.",
"Only images can be used as contact photos" => "Kun billedfiler kan bruges som profilbilleder",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "Størrelsen af \"{filename}\" overstiger de tilladte {size}",
"Error adding to group." => "Fejl ved tilføjelse til gruppe.",
"Error removing from group." => "Fejl ved fjernelse fra gruppe.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Du har markeret mere end 300 kontakter.\nDet vil sandsynligvis fejle! Klik her hvis du vil prøve alligevel.",
"Error setting {name} as favorite." => "Kunne ikke indstille {name} som favorit.",
"Merge contacts" => "Sammenlæg kontakter",
"Add group" => "Tilføj gruppe",
"OK" => "OK",
"Could not find contact: {id}" => "Kunne ikke finde kontakt: {id}",
"Edit profile picture" => "Redigér profilbillede",
"Crop photo" => "Beskær billede",
"Error parsing date: {date}" => "Fejl under læsning af dato: {date}",
"# groups" => "# grupper",
"Error parsing birthday {bday}" => "Fejl ved indlæsning af fødselsdag {bday}",
"The backend does not support multi-byte characters." => "Backenden understøtter ikke multi-byte karakterer",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Nogle kontakter er markeret til sletning, men er endnu ikke slettet. Vent venligst på, at de bliver slettet.",
"Click to undo deletion of {num} contacts" => "Klik for at fortryde sletning af {num} kontakter",
"Cancelled deletion of {num} contacts" => "annullerede sletning af {num} kontakter",
"Add" => "Tilføj",
"Contact is already in this group." => "Kontaktperson er allerede i denne gruppe.",
"Contacts are already in this group." => "Kontakterpersoner er allerede i denne gruppe.",
"Couldn't get contact list." => "Kunne ikke hente liste over kontaktpersoner.",
"Contact is not in this group." => "Kontaktperson er ikke i denne gruppe.",
"Contacts are not in this group." => "Kontakterpersoner er ikke i denne gruppe.",
"A group named \"{group}\" already exists" => "En gruppe ved navnet \"{group}\", eksisterer allerede",
"Failed renaming group: {error}" => "Kunne ikke omdøbe gruppe: {error}",
"You can drag groups to\narrange them as you like." => "Du kan trække grupper til⏎ arrangér dem som du vil.",
"Failed adding group: {error}" => "Kunne ikke tilføje gruppe: {error}",
"All" => "Alle",
"Favorites" => "Foretrukne",
"Shared by {owner}" => "Delt af {owner}",
"Not grouped" => "Ikke i gruppe",
"Failed loading groups: {error}" => "Kunne ikke hente grupper: {error}",
"Please choose the addressbook" => "Vælg venligst adressebog",
"Import into..." => "Importér til...",
"Error loading import template" => "Fejl ved hentning af importskabelon ",
"Import contacts" => "Importer kontakter",
"Import" => "Importer",
"Importing..." => "Importerer...",
"Import done" => "Import fuldført",
"Close" => "Luk",
"Error, missing parameters: " => "Fejl, mangler parametre:",
"Failed loading photo: {error}" => "Kunne ikke hente billede: {error}",
"You do not have permissions to see this contact" => "Du har ikke rettigheder til at se denne kontaktperson",
"Contact not found" => "Kontakt ikke fundet",
"You do not have permissions to see these contacts" => "Du har ikke rettigheder til at se disse kontaktpersoner",
"You do not have permissions add contacts to the address book" => "Du har ikke rettigheder til at føje kontaktpersoner til denne adressebog",
"The backend for this address book does not support adding contacts" => "Denne adressebogs system understøtter ikke tilføjelse af kontakter",
"You do not have permissions to delete this contact" => "Du har ikke rettigheder til at slette denne kontaktperson",
"The backend for this address book does not support deleting contacts" => "Denne adressebogs system understøtter ikke sletning af kontakter",
"Unknown error" => "Ukendt fejl",
"Access denied" => "Adgang nægtet",
"The backend for this address book does not support updating" => "Systemet for denne adressebog understøtter ikke opdatering",
"You don't have permissions to delete the address book." => "Du har ikke rettigheder til at slette denne adressebog",
"Address book not found" => "Adressebog ikke fundet",
"You do not have permissions to update this contact" => "Du har ikke rettigheder til at opdatere denne kontaktperson",
"The backend for this contact does not support updating it" => "Systemet for denne kontakt understøtter ikke opdatering",
"This backend does not support adding contacts" => "Dette system understøtter ikke tilføjelse af kontakter",
"Property not found" => "Egenskab ikke fundet",
" Missing IM parameter for: " => "Manglende IM-parameter for:",
"Unknown IM: " => "Ukendt IM:",
"{name}'s Birthday" => "{name}s fødselsdag",
"Error creating address book" => "Fejl ved oprettelse af adressebog",
"The \"%s\" backend does not support deleting address books" => "\"%s\" backenden understøtter ikke sletning af adressebøger",
"You do not have permissions to delete the \"%s\" address book" => "Du har ikke tilladelse til at slette \"%s\" adressebog",
"Error deleting address book" => "Fejl ved sletning af adressebog",
"Error creating contact." => "Fejl ved oprettelse af kontaktperson.",
"Error creating contact" => "Fejl ved oprettelse af kontakt",
"Error deleting contact" => "Fejl ved sletning af kontakt",
"Error retrieving contact" => "Fejl ved hentning af kontaktperson.",
"Error saving contact" => "Kunne ikke gemme kontaktpersonen.",
"Error removing contact from other address book." => "Fejl ved fjernelse af kontaktperson fra anden adressebog.",
"Error getting moved contact" => "Fejl ved hentning af flyttet kontakt",
"Couldn't find contact." => "Kunne ikke finde kontakt.",
"No contact data in request." => "Ingen kontakt oplysninger i anmodningen.",
"Error merging into contact." => "Fejl ved indfletning til kontaktperson.",
"Error saving contact to backend." => "Kunne ikke gemme kontakt på server.",
"Property name is not set." => "Egenskabsnavn er ikke angivet.",
"Property checksum is not set." => "Tjeksum for egenskab er ikke angivet.",
"Information about vCard is incorrect. Please reload the page." => "Informationen om vCard er forkert. Genindlæs siden.",
"Error updating contact" => "Kunne ikke opdatere kontakt",
"Error saving contact to backend" => "Kunne ikke gemme kontakt til server",
"Error getting user photo" => "Fejl ved indlæsning af brugerfoto",
"No photo path was submitted." => "Der blev ikke medsendt en sti til fotoet.",
"Error loading image from cache" => "Kunne ikke indlæse billede fra cache.",
"Error getting PHOTO property." => "Fejl ved indlæsning af PHOTO feltet.",
"Error saving contact." => "Kunne ikke gemme kontaktpersonen.",
"No group name given." => "Intet gruppenavn givet.",
"Error adding group." => "Fejl ved tilføjelse af gruppe.",
"No group name to rename from given." => "Intet gruppenavn at omdøbe fra det givne.",
"No group name to rename to given." => "Intet gruppenavn at omdøbe til det givne.",
"Error renaming group." => "Fejl ved omdøbning af gruppenavn.",
"Group ID missing from request." => "Gruppe-id mangler i forespørgsel.",
"Group name missing from request." => "Gruppenavn mangler i forespørgsel.",
"Contact ID missing from request." => "Kontaktpersons-id mangler i forespørgsel.",
"No file was uploaded. Unknown error" => "Ingen fil blev uploadet. Ukendt fejl.",
"There is no error, the file uploaded with success" => "Der skete ingen fejl, filen blev succesfuldt uploadet",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Den uploadede fil er større end upload_max_filesize indstillingen i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
"The uploaded file was only partially uploaded" => "Filen blev kun delvist uploadet.",
"No file was uploaded" => "Ingen fil uploadet",
"Missing a temporary folder" => "Manglende midlertidig mappe.",
"Failed to write to disk" => "Fejl ved skrivning til disk.",
"Not enough storage available" => "Der er ikke nok plads til rådlighed",
"Attempt to upload blacklisted file:" => "Forsøg på at oploade sortlistede filer:",
"Error uploading contacts to storage." => "Kunne ikke uploade kontaktepersoner til midlertidig opbevaring.",
"Error moving file to imports folder." => "Kunne ikke flytte filer til importmappe.",
"You do not have permissions to import into this address book." => "Du har ikke rettigheder til at importere til denne adressebog",
"File name missing from request." => "Filnavn mangler fra forespørgsel.",
"Progress key missing from request." => "Fremskridts nøglen mangler fra anmodningen.",
"Attempt to access blacklisted file:" => "Forsøg på at tilgå sortlistet fil:",
"No key is given." => "Ingen værdi er givet.",
"No value is given." => "Ingen værdi er givet.",
"Could not set preference: " => "Kunne ikke sætte præference:",
"Contact" => "Kontaktperson",
"Other" => "Andet",
"HomePage" => "Hjemmeside",
"Jabber" => "Jabber",
"Internet call" => "Internet opkald",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Google Talk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Arbejde",
"Home" => "Hjemme",
"Mobile" => "Mobil",
"Text" => "SMS",
"Voice" => "Telefonsvarer",
"Message" => "Besked",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Personsøger",
"Internet" => "Internet",
"Friends" => "Venner",
"Family" => "Familie",
"Enable LDAP Backend" => "Aktiver LDAP Backend",
"Enable LDAP backend for the contacts application" => "Aktiver LDAP backend for kontakt programmet",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Advarsel: LDAP backend er i beta tilstand, anvend med forsigtighed",
"New contact" => "Ny kontakt",
"Group name" => "Gruppe navn",
"New group" => "Ny gruppe",
"Address books" => "Adressebøger",
"Display name" => "Vist navn",
"Add Address Book" => "Tilføj Adressebog",
"Add LDAP Address Book" => "Tilføj LDAP adressebog",
"Automatic format" => "Automatisk format",
"Select file..." => "Vælg fil...",
"(De-)select all" => "(Fra)vælg alle",
"Sort order" => "Sorteringsorden",
"First- Lastname" => "For- efernavn",
"Last-, Firstname" => "For-, efternavn",
"Delete" => "Slet",
"Groups" => "Grupper",
"Download" => "Download",
"Merge" => "Flet",
"Email" => "E-mail",
"Phone" => "Telefon",
"Address" => "Adresse",
"Group" => "Gruppe",
"Keyboard shortcuts" => "Tastaturgenveje",
"Navigation" => "Navigering",
"Next contact in list" => "Næste kontaktperson i listen",
"Previous contact in list" => "Forrige kontaktperson i listen",
"Expand/collapse current addressbook" => "Udvid/sammenfold nuværende adressebog",
"Next addressbook" => "Næste adressebog",
"Previous addressbook" => "Forrige adressebog",
"Actions" => "Handlinger",
"Refresh contacts list" => "Genindlæs kontaktliste",
"Add new contact" => "Tilføj ny kontaktperson",
"Add new addressbook" => "Tilføj ny adressebog",
"Delete current contact" => "Slet aktuelle kontaktperson",
"You have no contacts in your address book or your address book is disabled." => "Du har ingen kontaktpersoner i din adressebog eller din adressebog er ikke aktiv.",
"Add a new contact or import existing contacts from a VCF file." => "Tilføj en ny kontakt eller importer eksisterende kontakt fra en VCF fil.",
"Which contact should the data be merged into?" => "Hvilken kontaktperson skal data føjes til?",
"Delete the other(s) after successful merge?" => "Slet de andre efter gennemgørt sammenfletning?",
"Compose mail" => "Skriv mail",
"Delete current photo" => "Slet nuværende foto",
"Edit current photo" => "Rediger nuværende foto",
"Upload new photo" => "Upload nyt foto",
"Select photo from Files" => "Vælg foto fra Filer",
"Favorite" => "Foretrukken",
"Name" => "Navn",
"First name" => "Fornavn",
"Additional names" => "Mellemnavne",
"Last name" => "Efternavn",
"Address book" => "Adressebog",
"Nickname" => "Kaldenavn",
"Title" => "Titel",
"Organization" => "Organisation",
"Birthday" => "Fødselsdag",
"Website" => "Hjemmeside",
"Instant messaging" => "Instant Messaging",
"Notes go here..." => "Skriv noter her...",
"Add field..." => "Tilføj felt...",
"Instant Messaging" => "Instant Messaging",
"Note" => "Note",
"Web site" => "Hjemmeside",
"Preferred" => "Foretrukken",
"Please specify a valid email address." => "Indtast venligst en gyldig email-adresse.",
"someone@example.com" => "nogen@eksempel.com",
"Mail to address" => "Send mail til adresse",
"Delete email address" => "Slet email-adresse",
"Enter phone number" => "Indtast telefonnummer",
"Go to web site" => "Gå til web site",
"View on map" => "Vis på kort",
"Street address" => "Gade",
"Postal code" => "Postnummer",
"City" => "By",
"State or province" => "Stat eller provins",
"Country" => "Land",
"Instant Messenger" => "Instant Messenger",
"Active" => "Aktiv",
"Share" => "Del",
"Export" => "Exporter",
"CardDAV link" => "CardDAV link",
"Edit" => "Rediger",
"Addressbook URI" => "Adressebog URI",
"URI" => "URI",
"Description" => "Beskrivelse",
"LDAP URL" => "LDAP URL",
"Anonymous" => "Anonymt",
"Read-only" => "Skrivebeskyttet",
"Read-Only" => "Skrivebeskyttet",
"User" => "Bruger",
"Password" => "Kodeord",
"Page size" => "Sidestørrelse",
"Base DN for search" => "Base DN for søgning",
"Base DN" => "Base DN",
"Search filter" => "Søgefilter",
"Filter" => "Filter",
"Copy from (Warning, replaces current custom value)" => "Kopier fra (Advarsel, dete erstatter eksisterende data)"
);
